========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/networking-midonet.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

==================
networking-midonet
==================

This is the official Midonet Neutron plugin.

Documentation:

- http://docs.openstack.org/developer/networking-midonet/
- https://docs.midonet.org/
